@@ -27,8 +27,9 @@ Implementation Notes
 
 **Software and Dependencies:**
 
-* Adafruit CircuitPython firmware for the ESP8622 and M0-based boards:
-  https://github.com/adafruit/circuitpython/releases
+* Adafruit CircuitPython firmware for the supported boards:
+  https://circuitpython.org/downloads
+
 * Adafruit's Bus Device library: https://github.com/adafruit/Adafruit_CircuitPython_BusDevice
 """
 import math
@@ -36,9 +37,9 @@ import time
 
 from micropython import const
 
-import adafruit_bus_device.spi_device as spi_device
+from adafruit_bus_device import spi_device
 
-__version__ = "0.0.0-auto.0"
+__version__ = "2.2.16"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_MAX31865.git"
 
 # Register and other constant values:
@@ -70,7 +71,45 @@ _RTD_B = -5.775e-7
 
 
 class MAX31865:
-    """Driver for the MAX31865 thermocouple amplifier."""
+    """Driver for the MAX31865 thermocouple amplifier.
+
+    :param ~busio.SPI spi: SPI device
+    :param ~digitalio.DigitalInOut cs: Chip Select
+    :param int rtd_nominal: RTD nominal value. Defaults to :const:`100`
+    :param int ref_resistor: Reference resistance. Defaults to :const:`430.0`
+    :param int wires: Number of wires. Defaults to :const:`2`
+    :param int filter_frequency: . Filter frequency. Default to :const:`60`
+    :param int polarity: set to 1 if controller clock idles high. Default 0.
+
+
+    **Quickstart: Importing and using the MAX31865**
+
+        Here is an example of using the :class:`MAX31865` class.
+        First you will need to import the libraries to use the sensor
+
+        .. code-block:: python
+
+            import board
+            from digitalio import DigitalInOut, Direction
+            import adafruit_max31865
+
+        Once this is done you can define your `board.SPI` object and define your sensor object
+
+        .. code-block:: python
+
+            spi = board.SPI()
+            cs = digitalio.DigitalInOut(board.D5)  # Chip select of the MAX31865 board.
+            sensor = adafruit_max31865.MAX31865(spi, cs)
+
+
+        Now you have access to the :attr:`temperature` attribute
+
+        .. code-block:: python
+
+            temperature = sensor.temperature
+
+
+    """
 
     # Class-level buffer for reading and writing data with the sensor.
     # This reduces memory allocations but means the code is not re-entrant or
@@ -82,6 +121,7 @@ class MAX31865:
         spi,
         cs,
         *,
+        polarity=0,
         rtd_nominal=100,
         ref_resistor=430.0,
         wires=2,
@@ -90,7 +130,7 @@ class MAX31865:
         self.rtd_nominal = rtd_nominal
         self.ref_resistor = ref_resistor
         self._device = spi_device.SPIDevice(
-            spi, cs, baudrate=500000, polarity=0, phase=1
+            spi, cs, baudrate=500000, polarity=polarity, phase=1
         )
         # Set 50Hz or 60Hz filter.
         if filter_frequency not in (50, 60):
@@ -166,13 +206,15 @@ class MAX31865:
         config = self._read_u8(_MAX31865_CONFIG_REG)
         if val:
             config |= _MAX31865_CONFIG_MODEAUTO  # Enable auto convert.
+            config |= _MAX31865_CONFIG_BIAS  # Enable bias.
         else:
             config &= ~_MAX31865_CONFIG_MODEAUTO  # Disable auto convert.
+            config &= ~_MAX31865_CONFIG_BIAS  # Disable bias.
         self._write_u8(_MAX31865_CONFIG_REG, config)
 
     @property
     def fault(self):
-        """The fault state of the sensor.  Use ``clear_faults()`` to clear the
+        """The fault state of the sensor.  Use :meth:`clear_faults` to clear the
         fault state.  Returns a 6-tuple of boolean values which indicate if any
         faults are present:
 
@@ -205,6 +247,11 @@ class MAX31865:
         nominal value of the resistance-to-digital conversion and some math.  If you just want
         temperature use the temperature property instead.
         """
+        if self.auto_convert:
+            rtd = self._read_u16(_MAX31865_RTDMSB_REG)
+            if not rtd & 1:
+                rtd >>= 1
+                return rtd
         self.clear_faults()
         self.bias = True
         time.sleep(0.01)
